#
# spec file for package libu2f-host
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover  0
Name:           libu2f-host
Version:        1.1.6
Release:        lp151.2.6.1
Summary:        Yubico Universal 2nd Factor (U2F) Host C Library
License:        LGPL-2.1-or-later
Group:          Productivity/Networking/Security
URL:            https://developers.yubico.com/
Source0:        https://developers.yubico.com/libu2f-host/Releases/%{name}-%{version}.tar.xz
Source1:        https://developers.yubico.com/libu2f-host/Releases/%{name}-%{version}.tar.xz.sig
Patch0:         libu2f-host-CVE-2018-20340.patch
Patch1:         libu2f-host-CVE-2019-9578.patch
BuildRequires:  libhidapi-devel
BuildRequires:  libtool
BuildRequires:  libzip
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(json-c) >= 0.10
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(udev)

%description
libu2f-host provide a command-line tool that implements
the host-side of the U2F protocol. There are APIs to talk to a U2F
device and perform the U2F Register and U2F Authenticate operations.

%package     -n %{name}%{sover}
Summary:        Library for Universal 2nd Factor (U2F)
Group:          Productivity/Networking/Security

%description -n %{name}%{sover}
Libu2f-host provide a C library that implements
the host-side of the U2F protocol.  There are APIs to talk to a U2F
device and perform the U2F Register and U2F Authenticate operations.

%package     -n %{name}-devel
Summary:        Development files for Universal 2nd Factor (U2F)
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description -n %{name}-devel
This package contains the header file needed to develop applications that
use Universal 2nd Factor (U2F).

%package     -n u2f-host
Summary:        Tool to support Yubico's Universal 2nd Factor (U2F)
Group:          Productivity/Networking/Security
Requires:       %{name}%{sover} = %{version}

%description -n u2f-host
Command line tool that implements the host side of the Universal 2nd Factor (U2F) protocol.

%package        doc
Summary:        Documentation for the U2F protocol
Group:          Productivity/Networking/Security

%description    doc
Documentation files for the host side of the U2F protocol.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
%configure --disable-static --with-openssl --with-udevrulesdir=%{_udevrulesdir}
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} INSTALL="install -p"
find %{buildroot} -type f -name "*.la" -delete -print

%post
%{?udev_rules_update:%udev_rules_update}

%post   -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n u2f-host
%license COPYING
%doc AUTHORS NEWS ChangeLog README
%{_bindir}/u2f-host
%{_mandir}/man1/u2f-host.1%{?ext_man}
%dir %{_prefix}/lib/udev
%dir %{_udevrulesdir}
%{_udevrulesdir}/*-u2f.rules

%files doc
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/u2f-host/

%files -n %{name}%{sover}
%{_libdir}/%{name}.so.%{sover}
%{_libdir}/%{name}.so.%{sover}.1.6

%files -n %{name}-devel
%{_includedir}/u2f-host/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/*

%changelog
* Tue May 28 2019 Karol Babioch <kbabioch@suse.de>
- Added libu2f-host-CVE-2019-9578.patch: Fixed fix filling out of initresp
  (CVE-2019-9578 bsc#1128140)
* Fri Feb  8 2019 Karol Babioch <kbabioch@suse.de>
- Added libu2f-host-CVE-2018-20340.patch: Fixed an unchecked buffer, which
  could allow a buffer overflow with a custom made malicious USB device
  (bsc#1124781 CVE-2018-20340).
* Tue May 15 2018 kbabioch@suse.com
- Version 1.1.6 (released 2018-05-15)
  - Change waiting logic on authenticate to allow for faster feedback.
- Version 1.1.5 (released 2018-03-07)
  - Fix refcount when adding json_objects.
  - Handle fido2 keepalive.
  - Add udev rules for more devices.
* Wed Sep 13 2017 kkaempf@suse.com
- Version 1.1.4 (released 2017-09-01)
  - Added more u2f devices to the udev rulesets.
  - Increase buffer size, allowing for bigger certificates.
  - Add u2f.conf.sample for FreeBSD permission handling.
* Wed Oct 12 2016 t.gruner@katodev.de
- Version 1.1.3 (released 2016-10-04)
  - Added more u2f devices to the udev rulesets.
  - Fixup mac builds.
- Version 1.1.2 (released 2016-06-22)
  - Make authenticate return U2FH_OK if touch is set to not needed. Also minor fixes to error output of authenticate.
  - Documentation fixes.
  - Compilation fixes on visual studio.
  - Add udev rules for Feitian devices.
  - Add optional cmake build.
  - Change license of the commandline tool to LGPL 2.1+
- remove udev.patch
* Thu May 19 2016 t.gruner@katodev.de
- Add buildrequirement for libudev to select the rule for udev.
- Add udev directories in %%files
- Add udev rule for Feitian ePass FIDO (udev.patch)
- Change License for the library
* Wed Mar 23 2016 jengelh@inai.de
- Avoid undesired blank lines at start of descriptions.
  Expand description. Trim filelist.
* Mon Mar 21 2016 t.gruner@katodev.de
- Version 1.1.1 (released 2016-03-14)
  - Use correct index in u2fh_devs_discover()
  - Fix an issue where we left the authenticate loop early.
  - Fix an issue where authenticate remembered which devices to skip.
  - Stop validating the scheme of the origin.
  - Fixup a crash in u2fh_devs_discover() with closing unplugged devices.
  - Documentation fixes.
* Thu Feb 18 2016 t.gruner@katodev.de
- Version 1.1.0 (released 2016-02-15)
  - Add udev rules for more devices.
  - Don’t return success when no data is received.
  - Fix typos.
  - Make send_apdu send data like chrome does.
  - Don’t release json object that we don’t own no more.
  - Don’t do memcmp on uninitialized memory.
  - Add u2fh_authenticate2() and u2fh_register2().
  - Remove base64 padding (required by spec).
  - Use unsigned ints to prevent buffer overflows.
* Tue Oct  6 2015 t.gruner@katodev.de
- Remove fix in u2f-host/u2f-host.h
- Cleanup .spec file
* Fri Sep  4 2015 t.gruner@katodev.de
- Fix path in u2f-host/u2f-host.h
* Tue Sep  1 2015 t.gruner@katodev.de
- Version 1.0.0 (released 2015-08-27)
  - Add udev rules for older version of udev.
  - Add pam:// as an allowed protocol.
  - Stop using sleep(), use Sleep() on windows and usleep() on others.
  - Fixup tool name in help and manpage.
  - Add a timeout to the register and authenticate actions.
* Fri Jan 23 2015 t.gruner@katodev.de
- Version 0.0.4 (released 2015-01-22)
  - Add an exponential growing timeout for slow devices (PlugUp).
* Thu Jan  8 2015 t.gruner@katodev.de
- Version 0.0.3 (released 2015-01-08)
  - Change license to LGPLv2+ for the library.
  - Some improvements to internal communication code.
  - Some debug mode improvements, from Bram Vandoren.
* Tue Dec  9 2014 t.gruner@katodev.de
- Version 0.0.2 (released 2014-11-28)
  - Add more devices to udev.
* Tue Oct 28 2014 t.gruner@katodev.de
- Version 0.0 (released 2014-09-16)
  - Initial release.
